import logging


logging.basicConfig(
    level=logging.INFO, format="%(asctime)s; %(levelname)s; %(message)s"
)


__VERSION__ = "1.5.0a2"
__OME_NGFF_VERSION__ = "0.4"
__FRACTAL_TABLE_VERSION__ = "1"
